changeset 11410:db21cc7b40f0 v8.0.0589

patch 8.0.0589: :simalt still does not work commit https://github.com/vim/vim/commit/a21ccb7a974a96550c5cd99c4633e166d2083172 Author: Bram Moolenaar <Bram@vim.org> Date: Sat Apr 29 17:40:22 2017 +0200 patch 8.0.0589: :simalt still does not work Problem: :simalt still does not work. Solution: Use K_NOP instead of K_IGNORE. (Christian Brabandt)
author Christian Brabandt <cb@256bit.org>
date Sat, 29 Apr 2017 17:45:04 +0200
parents 7b39aa183f2e
children ab53b2f7ffc3
files src/gui_w32.c src/version.c
diffstat 2 files changed, 4 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/src/version.c
+++ b/src/version.c
@@ -765,6 +765,8 @@ static char *(features[]) =
 static int included_patches[] =
 {   /* Add new patch number below this line */
 /**/
+    589,
+/**/
     588,
 /**/
     587,
--- a/src/gui_w32.c
+++ b/src/gui_w32.c
@@ -2642,11 +2642,11 @@ ex_simalt(exarg_T *eap)
     }
     if (fill_typebuf)
     {
 	/* Put something in the typeahead buffer so that the message will get
 	 * processed. */
 	key_name[0] = K_SPECIAL;
 	key_name[1] = KS_EXTRA;
-	key_name[2] = KE_IGNORE;
+	key_name[2] = KE_NOP;
 	key_name[3] = NUL;
 	typebuf_was_filled = TRUE;
 	(void)ins_typebuf(key_name, REMAP_NONE, 0, TRUE, FALSE);
@@ -2642,11 +2642,11 @@ ex_simalt(exarg_T *eap)
     if (fill_typebuf)
     {
-	/* Put something in the typeahead buffer so that the message will get
+	/* Put a NOP in the typeahead buffer so that the message will get
 	 * processed. */
 	key_name[0] = K_SPECIAL;